@@ -1,6 +1,7 @@
 from .__about__ import __version__
 from ._colors import get_srgb1
 from ._main import Plotter, plot, plot_abs, plot_arg, plot_contours, plot_phase
+from ._riemann_sphere import riemann_sphere
 from ._tri import tricontour_abs, tripcolor
 from .benchmark import show_kovesi_test_image, show_test_function
 from .create import create_colormap, find_max_srgb_radius, show_circular, show_linear
@@ -19,6 +20,8 @@ __all__ = [
     "plot_phase",
     "plot_contours",
     #
+    "riemann_sphere",
+    #
     "tripcolor",
     "tricontour_abs",
     #
